/**
 * Compute (or read from metadata) various dataset stats: number of
 * transactions, number of items, max transaction lengths, upper bound to
 * d-index, h-index. See stats.h for more information.
 *
 * Copyright 2014 Matteo Riondato <matteo@cs.brown.edu>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

#include <iostream>
#include <string>
#include <unordered_map>
#include <unistd.h>
extern char *optarg;
extern int optind;
extern int optopt;
extern int opterr;
extern int optreset;

#include "stats.h"
#include "util.h"

using namespace std;

bool verbose = false;

/**
 * Print usage on stderr.
 */
void usage(const char *binary_name) {
	cerr << binary_name << ": compute (or read from metadata) dataset statistics" << endl;
	cerr << "USAGE: " << binary_name << " [-hiv] dataset" 
		<< endl;
	cerr << "\t-h: print this help message and exit" << endl;
	cerr << "\t-i: ignore metadata" << endl;
	cerr << "\t-v: verbose mode" << endl;
}

int main(int argc, char* argv[]) {
	bool look_for_metadata = true;
	int opt;
	while ((opt = getopt(argc, argv, "hiv")) != -1) {
		switch (opt) {
		case 'h':
			usage(argv[0]);
			return EXIT_SUCCESS;
			break;
		case 'i':
			look_for_metadata = false;
			break;
		case 'v':
			verbose = true;
			break;
		}
	}
	if (optind != argc - 1) {
		cerr << ERROR_HEADER << "wrong number of arguments" << endl;
		return EXIT_FAILURE;
	}

	// Compute dataset stats
	unordered_map<string, double> stats = get_stats(argv[argc - 1], look_for_metadata);

	// Print stats
	print_stats(stats);
}

